#!/bin/sh
prefix=/usr
bindir=${prefix}/bin
sbindir=${prefix}/sbin
infodir=${prefix}/share/info
man1dir=${prefix}/share/man/man1

${sbindir}/update-alternatives \
	--install ${infodir}/automake.info.gz automake-doc ${infodir}/automake1.11.info.gz 45 \
	--slave   ${man1dir}/automake.1.gz automake-man ${man1dir}/automake-1.11.1.gz \
	--slave   ${man1dir}/aclocal.1.gz aclocal-man ${man1dir}/aclocal-1.11.1.gz

